==> phpwiki-1.2.6.tbz: www/data-dist/phpwiki/locale/es/LC_MESSAGES/phpwiki.php <==
<?php

$locale["You entered an invalid login or password."] =
   "Se h&aacute; introducido un nombre de usuario o palabra de paso invalido.";
$locale["You are about to remove '%s' permanently!"] =
   "Va a borrar '%s' permanentemente!";
$locale["Click %shere%s to remove the page now."] =
   "Haga Click %aqu&iacute;% para borrar la p&aacute;gina ahora";
$locale["Otherwise press the \"Back\" button of your browser."] =
   "En caso contrario pulse el bot&oacute; \"Atr&aacute;s\" en su navegador";
$locale["Function not yet implemented."] =
   "Funci&oacute;n todav&iacute; no implementada";
$locale["Remove page"] =
   "Borrar p&aacute;gina";
$locale["Removed page '%s' succesfully."] =
   "P&aacute;gina '%s' borrada satisfactoriamente.";
$locale["templates/browse.html"] =
   "locale/es/templates/browse.html";
$locale["templates/editpage.html"] =
   "locale/es/templates/editpage.html";
$locale["templates/editlinks.html"] =
   "locale/es/templates/editlinks.html";
$locale["templates/message.html"] =
   "locale/es/templates/message.html";
$locale["./pgsrc"] =
   "locale/es/pgsrc";
$locale["WikiDiff::apply: line count mismatch: %s != %s"] =
   "WikiDiff::apply: conteo de l&iacute;neas difiere: %s != %s";
$locale["WikiDiff::_check: failed"] =
   "WikiDiff::_check: fall&oacute;";
$locale["WikiDiff::_check: edit sequence is non-optimal"] =
   "WikiDiff::_check: secuencia de edici&oacute;n no es &oacute;ptima";
$locale["WikiDiff Okay: LCS = %s"] =
   "WikiDiff Ok: LCS = %s";
$locale["Current page:"] =
   "P&aacute;gina actual:";
$locale["version %s"] =
   "versi&oacute;n %s";
$locale["last modified on %s"] =
   "modificado por &uacute;ltima vez el %s";
$locale["by %s"] =
   "por %s";
$locale["None"] =
   "Ninguno";
$locale["Archived page:"] =
   "P&aacute;gina archivada:";
$locale["Versions are identical"] =
   "Las versiones son id&eacute;nticas";
$locale["Diff of %s."] =
   "Diferencia de %s.";
$locale["FrontPage"] =
   "PaginaPrincipal";
$locale["Describe %s here."] =
   "Describe %s aqu&iacute;.";
$locale["Copy of %s"] =
   "Copia de %s";
$locale["No page name passed into editpage!"] =
   "No se h&aacute; pasado nombre de p&aacute;gina a editarpagina";
$locale["This page has been locked by the administrator and cannot be edited."] =
   "Esta p&aacute;gina ha sido bloqueada por el administrador y no puede ser editada.";
$locale["Sorry for the inconvenience."] =
   "Disculpe la inconveniencia.";
$locale["Problem while editing %s"] =
   "Problema al editar %s";
$locale["Searching for \"%s\" ....."] =
   "Buscando \"%s\" ...";
$locale["%d matches found in %d pages."] =
   "%d veces encontrado en %d p&aacute;ginas.";
$locale["Full Text Search Results"] =
   "Resultados de la bsqueda en el texto completo";
$locale["Cannot establish connection to database, giving up."] =
   "No se puede establecer conexi&oacute;n con la base de datos, me doy por vencido.";
$locale["Error message: %s"] =
   "Mensaje de error: %s";
$locale["Cannot open database %s, giving up."] =
   "No se puede abrir la base de datos %s , me doy por vencido.";
$locale["Insert/update failed: %s"] =
   "Inserci&oacute;n/Actualizaci&oacute;n fall&oacute;: %s";
$locale["Delete on %s failed: %s"] =
   "Eliminaci&oacute;n en %s fall&oacute;: %s";
$locale["Insert into %s failed: %s"] =
   "Inserci&oacute;n en %s fall&oacute;: %s";
$locale["MySQL error: %s"] =
   "Error de MySQL: %s";
$locale["Error writing page '%s'"] =
   "Error al escribir la p&aacute;gina `%s'";
$locale["Cannot delete '%s' from table '%s'"] =
   "No se puede borrar '%s' de la tabla '%s'";
$locale["Enter a page name"] =
   "Escriba un nombre de p&aacute;gina";
$locale["Go"] =
   "Aceptar";
$locale["Show the page source and references"] =
   "Mostrar el c&oacute;digo fuente de la p&aacute;gina y referencias";
$locale["PageInfo"] =
   "InformacionDeLaPagina";
$locale["Page name '%s' is not in the database"] =
   "El nombre de la p&aacute;gina `%s' no est&aacute; en la base de datos";
$locale["Current version"] =
   "Versi&oacute;n actual:";
$locale["Archived version"] =
   "Versi&oacute;n archivada:";
$locale["RecentChanges"] =
   "CambiosRecientes";
$locale["PhpWiki is unable to save your changes, because another user edited and saved the page while you were editing the page too. If saving proceeded now changes from the previous author would be lost."] =
   "PhpWiki no es capaz de grabar sus cambios, debido a que otro usuarioh&aacute; editado y guardado la p&aacute;gina mientras usted estaba editando esta p&aacute;gina. Si se guarda ahora los cambios del autor anterior se podr&iacute;an perder.";
$locale["In order to recover from this situation follow these steps:"] =
   "Para restaurar esta situaci&oacute;n siga los siguientes pasos:";
$locale["Use your browser's <b>Back</b> button to go back to the edit page."] =
   "Use el bot&oacute;n <b>Atr&aacute;s<b> para retornar a la p&aacute;gina editada";
$locale["Copy your changes to the clipboard or to another temporary place (e.g. text editor)."] =
   "Copie sus cambios al portapapeles o a otro sitio temporal (p.ej. editor de textos).";
$locale["<b>Reload</b> the page. You should now see the most current version of the page. Your changes are no longer there."] =
   "<b>Vuelva a cargar</b> la p&aacute;gina. Ahora podr&aacute; ver la versi&oacute;n mas actual de la p&aacute;gina. Sus cambios no est&aacute;n ah&iacute;.";
$locale["Make changes to the file again. Paste your additions from the clipboard (or text editor)."] =
   "Haga cambios a la p&aacute;gina otra vez. Pegue sus modificaciones del portapapeles (o del editor de textos).";
$locale["Press <b>Save</b> again."] =
   "Pulse <b>Guardar<b> otra vez.";
$locale["Problem while updating %s"] =
   "Problema al editar %s";
$locale["Thank you for editing %s."] =
   "Gracias por editar %s.";
$locale["Your careful attention to detail is much appreciated."] =
   "Se agradece una cuidadosa atenci&oacute;n a los detalles.";
$locale["Title Search Results"] =
   "Resultados de la bsqueda en el texto completo";
$locale["Inserting page %s, version %s from %s"] =
   "Insertando p&aacute;gina %s, versi&oacute;n %s de %s";
$locale["WikiFatalError"] =
   "ErrorFatalDeWiki";
$locale["Search"] =
   "Buscar";
$locale["Nesting depth exceeded in SetHTMLOutputMode"] =
   "L&iacute;mites de la pila excedidos en SetHTMLOutputMode";
$locale["%d best incoming links:"] =
   "%d mejores enlaces de entrada:";
$locale["%d best outgoing links:"] =
   "%d mejores enlaces de salida:";
$locale["%d most popular nearby:"] =
   "%d las m&aacute;s populares:";

;?>

==> phpwiki-1.2.10_1.tbz: www/data-dist/phpwiki/locale/es/LC_MESSAGES/phpwiki.php <==
<?php

$locale["You entered an invalid login or password."] =
   "Se h&aacute; introducido un nombre de usuario o palabra de paso invalido.";
$locale["You are about to remove '%s' permanently!"] =
   "Va a borrar '%s' permanentemente!";
$locale["Click %shere%s to remove the page now."] =
   "Haga Click %aqu&iacute;% para borrar la p&aacute;gina ahora";
$locale["Otherwise press the \"Back\" button of your browser."] =
   "En caso contrario pulse el bot&oacute; \"Atr&aacute;s\" en su navegador";
$locale["Function not yet implemented."] =
   "Funci&oacute;n todav&iacute; no implementada";
$locale["Remove page"] =
   "Borrar p&aacute;gina";
$locale["Removed page '%s' succesfully."] =
   "P&aacute;gina '%s' borrada satisfactoriamente.";
$locale["templates/browse.html"] =
   "locale/es/templates/browse.html";
$locale["templates/editpage.html"] =
   "locale/es/templates/editpage.html";
$locale["templates/editlinks.html"] =
   "locale/es/templates/editlinks.html";
$locale["templates/message.html"] =
   "locale/es/templates/message.html";
$locale["./pgsrc"] =
   "locale/es/pgsrc";
$locale["WikiDiff::apply: line count mismatch: %s != %s"] =
   "WikiDiff::apply: conteo de l&iacute;neas difiere: %s != %s";
$locale["WikiDiff::_check: failed"] =
   "WikiDiff::_check: fall&oacute;";
$locale["WikiDiff::_check: edit sequence is non-optimal"] =
   "WikiDiff::_check: secuencia de edici&oacute;n no es &oacute;ptima";
$locale["WikiDiff Okay: LCS = %s"] =
   "WikiDiff Ok: LCS = %s";
$locale["Current page:"] =
   "P&aacute;gina actual:";
$locale["version %s"] =
   "versi&oacute;n %s";
$locale["last modified on %s"] =
   "modificado por &uacute;ltima vez el %s";
$locale["by %s"] =
   "por %s";
$locale["None"] =
   "Ninguno";
$locale["Archived page:"] =
   "P&aacute;gina archivada:";
$locale["Versions are identical"] =
   "Las versiones son id&eacute;nticas";
$locale["Diff of %s."] =
   "Diferencia de %s.";
$locale["FrontPage"] =
   "PaginaPrincipal";
$locale["Describe %s here."] =
   "Describe %s aqu&iacute;.";
$locale["Copy of %s"] =
   "Copia de %s";
$locale["No page name passed into editpage!"] =
   "No se h&aacute; pasado nombre de p&aacute;gina a editarpagina";
$locale["This page has been locked by the administrator and cannot be edited."] =
   "Esta p&aacute;gina ha sido bloqueada por el administrador y no puede ser editada.";
$locale["Sorry for the inconvenience."] =
   "Disculpe la inconveniencia.";
$locale["Problem while editing %s"] =
   "Problema al editar %s";
$locale["Searching for \"%s\" ....."] =
   "Buscando \"%s\" ...";
$locale["%d matches found in %d pages."] =
   "%d veces encontrado en %d p&aacute;ginas.";
$locale["Full Text Search Results"] =
   "Resultados de la bsqueda en el texto completo";
$locale["Cannot establish connection to database, giving up."] =
   "No se puede establecer conexi&oacute;n con la base de datos, me doy por vencido.";
$locale["Error message: %s"] =
   "Mensaje de error: %s";
$locale["Cannot open database %s, giving up."] =
   "No se puede abrir la base de datos %s , me doy por vencido.";
$locale["Insert/update to table 'wiki' failed: %s"] =
   "Inserci&oacute;n/Actualizaci&oacute;n 'wiki' fall&oacute;: %s";
$locale["Delete on %s failed: %s"] =
   "Eliminaci&oacute;n en %s fall&oacute;: %s";
$locale["Insert into %s failed: %s"] =
   "Inserci&oacute;n en %s fall&oacute;: %s";
$locale["Insert/update into table 'archive' failed: %s"] =
   "Inserci&oacute;n/Actualizaci&oacute;n 'archive' fall&oacute;: %s";
$locale["MSSQL error: %s"] =
   "Error de MSSQL: %s";
$locale["Insert/Update failed: %s"] =
   "Inserci&oacute;n/Actualizaci&oacute;n fall&oacute;: %s";
$locale["Cannot delete '%s' from table '%s'"] =
   "No se puede borrar '%s' de la tabla '%s'";
$locale["MySQL error: %s"] =
   "Error de MySQL: %s";
$locale["Error writing page '%s'"] =
   "Error al escribir la p&aacute;gina `%s'";
$locale["Enter a page name"] =
   "Escriba un nombre de p&aacute;gina";
$locale["Go"] =
   "Aceptar";
$locale["Show the page source and references"] =
   "Mostrar el c&oacute;digo fuente de la p&aacute;gina y referencias";
$locale["PageInfo"] =
   "InformacionDeLaPagina";
$locale["Page name '%s' is not in the database"] =
   "El nombre de la p&aacute;gina `%s' no est&aacute; en la base de datos";
$locale["Current version"] =
   "Versi&oacute;n actual:";
$locale["Archived version"] =
   "Versi&oacute;n archivada:";
$locale["RecentChanges"] =
   "CambiosRecientes";
$locale["PhpWiki is unable to save your changes, because another user edited and saved the page while you were editing the page too. If saving proceeded now changes from the previous author would be lost."] =
   "PhpWiki no es capaz de grabar sus cambios, debido a que otro usuarioh&aacute; editado y guardado la p&aacute;gina mientras usted estaba editando esta p&aacute;gina. Si se guarda ahora los cambios del autor anterior se podr&iacute;an perder.";
$locale["In order to recover from this situation follow these steps:"] =
   "Para restaurar esta situaci&oacute;n siga los siguientes pasos:";
$locale["Use your browser's <b>Back</b> button to go back to the edit page."] =
   "Use el bot&oacute;n <b>Atr&aacute;s<b> para retornar a la p&aacute;gina editada";
$locale["Copy your changes to the clipboard or to another temporary place (e.g. text editor)."] =
   "Copie sus cambios al portapapeles o a otro sitio temporal (p.ej. editor de textos).";
$locale["<b>Reload</b> the page. You should now see the most current version of the page. Your changes are no longer there."] =
   "<b>Vuelva a cargar</b> la p&aacute;gina. Ahora podr&aacute; ver la versi&oacute;n mas actual de la p&aacute;gina. Sus cambios no est&aacute;n ah&iacute;.";
$locale["Make changes to the file again. Paste your additions from the clipboard (or text editor)."] =
   "Haga cambios a la p&aacute;gina otra vez. Pegue sus modificaciones del portapapeles (o del editor de textos).";
$locale["Press <b>Save</b> again."] =
   "Pulse <b>Guardar<b> otra vez.";
$locale["Problem while updating %s"] =
   "Problema al editar %s";
$locale["Thank you for editing %s."] =
   "Gracias por editar %s.";
$locale["Your careful attention to detail is much appreciated."] =
   "Se agradece una cuidadosa atenci&oacute;n a los detalles.";
$locale["Title Search Results"] =
   "Resultados de la bsqueda";
$locale["Inserting page %s, version %s from %s"] =
   "Insertando p&aacute;gina %s, versi&oacute;n %s de %s";
$locale["WikiFatalError"] =
   "ErrorFatalDeWiki";
$locale["Search"] =
   "Buscar";
$locale["%d best incoming links:"] =
   "%d mejores enlaces de entrada:";
$locale["%d best outgoing links:"] =
   "%d mejores enlaces de salida:";
$locale["%d most popular nearby:"] =
   "%d las m&aacute;s populares:";

;?>
